Module oqtant.tests.integration.conftest
========================================

Functions
---------


`delete_user_test_jobs(token: str) ‑> None`
:


`external_user_id()`
:


`get_token() ‑> str | None`
:


`get_user(token: str, token_data: Dict) ‑> Optional[bert_schemas.user.UserResponse]`
:


`get_user_jobs(token: str) ‑> Optional[List[Dict]]`
:


`oqtant_client()`
:


`pytest_configure(config)`
:


`pytest_sessionfinish(session, exitstatus)`
:


`settings()`
:


`user()`
:


`user_token()`
:


`verify_token(token: str) ‑> Optional[Dict]`
:
